summaryrefslogtreecommitdiffstats
path: root/src/kvilib/irc/kvi_ircmask.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/kvilib/irc/kvi_ircmask.cpp')
-rw-r--r--src/kvilib/irc/kvi_ircmask.cpp36
1 files changed, 18 insertions, 18 deletions
diff --git a/src/kvilib/irc/kvi_ircmask.cpp b/src/kvilib/irc/kvi_ircmask.cpp
index 4460cba..cb90c00 100644
--- a/src/kvilib/irc/kvi_ircmask.cpp
+++ b/src/kvilib/irc/kvi_ircmask.cpp
@@ -29,17 +29,17 @@
#include "kvi_ircmask.h"
/*
- @doc: irc_tqmasks
+ @doc: irc_masks
@title:
- Irc tqmasks
+ Irc masks
@type:
generic
@short:
- Decription of the standard IRC tqmasks
+ Decription of the standard IRC masks
@keyterms:
- irc tqmasks , nickname , username , hostname , wildcard
+ irc masks , nickname , username , hostname , wildcard
@body:
- [big]Simple tqmasks[/big][br]
+ [big]Simple masks[/big][br]
An irc tqmask is a string in a special format that identifies an user on irc.[br]
The standard basic format is:[br]
[b]<nick>!<username>@<host>[/b][br]
@@ -68,23 +68,23 @@
The IP address can be either in IPV4 format or in IPV6 format.[br]
Some (weird from my point of view) servers hide certain parts of the IP address to
prevent attacks to the user's machine.[br]
- Here are some examples of full irc-tqmasks:[br]
+ Here are some examples of full irc-masks:[br]
Pragma!^pragma@staff.kvirc.net[br]
[jazz]!~jazz@jazz.myhome.com[br]
luke!=skywalker@212.213.41.12[br]
HAN!^solo@ff0f:a0a0:1011::ea80:1[br]
Darth!vader@210.11.12.XXX[br]
- The irc-tqmasks are [b]case insensitive[/b].[br]
+ The irc-masks are [b]case insensitive[/b].[br]
[br]
- [big]Wildcard tqmasks[/big][br]
- In some contexts the irc-tqmasks can contain '*' and '?' wildcards.[br]
- The wild tqmasks are used to "match" an user within a set of them.[br]
+ [big]Wildcard masks[/big][br]
+ In some contexts the irc-masks can contain '*' and '?' wildcards.[br]
+ The wild masks are used to "match" an user within a set of them.[br]
'*' matches any sequence (eventually empty) of characters and '?' matches a single character.[br]
Wildcards are allowed only in the <nick> , <user> and <host> part: so the
"wildest" tqmask possible is:[br]
[b]*!*@*[/b][br]
that designates "any nickname, any username on any host".[br]
- Here are some examples of wild tqmasks:[br]
+ Here are some examples of wild masks:[br]
Pragma!*pragma@212.101.102.*: matches any user with nickname "Pragma" , username that ends with "pragma" and
coming from any machine on the 212.101.102 network.[br]
*!solo@*.starwars.org: matches any nick with username solo (no prefix!) coming from any machine in
@@ -293,7 +293,7 @@ bool KviIrcMask::hasNumericHost() const
unsigned short uc;
while((uc = p->tqunicode()))
{
- if(uc == '.')nPoints++; // ipv6 tqmasks can contain dots too!
+ if(uc == '.')nPoints++; // ipv6 masks can contain dots too!
else {
if(uc == ':')nDoublePoints++;
else {
@@ -341,7 +341,7 @@ bool KviIrcMask::hasNumericHost() const
* 19: *!~user@*.host.top (*!~user@XXX.XXX.*)
* 20: nick!*user@*.host.top (nick!*user@XXX.XXX.*)
* 21: *!*user@*.host.top (*!user@*XXX.XXX.*)
* smart versions of the tqmasks 17-21 that try take care of tqmasked ip addresses
* in the form xxx.xxx.INVALID-TOP-MASK
* 22: nick!~user@*.host.top (nick!~user@XXX.XXX.*)
* 23: nick!*@*.host.top (nick!*@XXX.XXX.*)
@@ -363,13 +363,13 @@ bool KviIrcMask::hasNumericHost() const
** - i line, no ident
*/
-static unsigned char tqmaskTable[27][3] = {
+static unsigned char maskTable[27][3] = {
{ 0 , 0 , 0 }, //0 means normal block
{ 0 , 0 , 2 }, //2 in the third field means type *.abc.host.top (or XXX.XXX.XXX.*) host tqmask
{ 0 , 0 , 1 }, //2 in the second field means *user (strip prefixes)
{ 0 , 1 , 0 }, //1 means *
{ 0 , 1 , 2 }, //3 in the third field means type *.host.top (or XXX.XXX.*) host tqmask
- { 0 , 1 , 1 }, //4 in the third field is like 3 but tries to detect tqmasked ip addresses too
+ { 0 , 1 , 1 }, //4 in the third field is like 3 but tries to detect masked ip addresses too
{ 1 , 0 , 0 },
{ 1 , 0 , 2 },
{ 1 , 0 , 1 },
@@ -396,9 +396,9 @@ static unsigned char tqmaskTable[27][3] = {
void KviIrcMask::tqmask(TQString &szMask,MaskType eMaskType) const
{
if((((int)eMaskType) > 26)||(((int)eMaskType) < 0))eMaskType = NickUserHost;
- szMask = tqmaskTable[((int)eMaskType)][0] ? m_szWild : m_szNick;
+ szMask = maskTable[((int)eMaskType)][0] ? m_szWild : m_szNick;
szMask.append("!");
- switch(tqmaskTable[((int)eMaskType)][1])
+ switch(maskTable[((int)eMaskType)][1])
{
case 0:
szMask.append(m_szUser);
@@ -421,7 +421,7 @@ void KviIrcMask::tqmask(TQString &szMask,MaskType eMaskType) const
break;
}
szMask.append('@');
- switch(tqmaskTable[((int)eMaskType)][2])
+ switch(maskTable[((int)eMaskType)][2])
{
case 0:
szMask.append(m_szHost);
@@ -341,7 +341,7 @@ bool KviIrcMask::hasNumericHost() const
* 20: nick!*user@*.host.top (nick!*user@XXX.XXX.*)
* 21: *!*user@*.host.top (*!user@*XXX.XXX.*)
-* smart versions of the tqmasks 17-21 that try take care of tqmasked ip addresses
+* smart versions of the masks 17-21 that try take care of masked ip addresses
* in the form xxx.xxx.INVALID-TOP-MASK
* 22: nick!~user@*.host.top (nick!~user@XXX.XXX.*)